@@ -12,10 +12,16 @@ import distfit
 
 # %% Multiple distributions as input
 from distfit import distfit
-X = np.random.normal(0, 2, 10000)
+X = np.random.normal(0, 2, 1000)
 y = [-8, -6, 0, 1, 2, 3, 4, 5, 6]
-dist = distfit(stats='RSS', distr=['norm', 't', 'gamma'])
+dist = distfit(stats='RSS', distr=['expon', 't', 'gamma', 'lognorm'])
+dist = distfit(stats='RSS', distr=['lognorm'])
 results = dist.fit_transform(X)
+dist.plot()
+
+results = dist.predict(y, alpha=0.01)
+
+print(dist.model)
 
 # %% Discrete example
 from distfit import distfit
